aboutsummaryrefslogtreecommitdiffstats
path: root/railties/environments/development.rb
diff options
context:
space:
mode:
authorDavid Heinemeier Hansson <david@loudthinking.com>2005-09-13 10:07:37 +0000
committerDavid Heinemeier Hansson <david@loudthinking.com>2005-09-13 10:07:37 +0000
commit6a0e41c158d327967e75fc93f001452449e8afe1 (patch)
treeda3c23709353ad237aa710443b69d96aaf0e1bd0 /railties/environments/development.rb
parent6e8e9c20cb9ad2ec3c880ad81e3ecead0bc3cf28 (diff)
downloadrails-6a0e41c158d327967e75fc93f001452449e8afe1.tar.gz
rails-6a0e41c158d327967e75fc93f001452449e8afe1.tar.bz2
rails-6a0e41c158d327967e75fc93f001452449e8afe1.zip
Reformed environments files to the new config style
git-svn-id: http://svn-commit.rubyonrails.org/rails/trunk@2232 5ecf4fe2-1ee6-0310-87b1-e25e094e27de
Diffstat (limited to 'railties/environments/development.rb')
-rw-r--r--railties/environments/development.rb17
1 files changed, 10 insertions, 7 deletions
diff --git a/railties/environments/development.rb b/railties/environments/development.rb
index d214c666d0..a151c3ba11 100644
--- a/railties/environments/development.rb
+++ b/railties/environments/development.rb
@@ -1,14 +1,17 @@
# In the development environment your application's code is reloaded on
# every request. This slows down response time but is perfect for development
# since you don't have to restart the webserver when you make code changes.
+config.cache_classes = false
# Log error messages when you accidentally call methods on nil.
-require 'active_support/whiny_nil'
+config.whiny_nils = true
-# Reload code; show full error reports; disable caching.
-Dependencies.mechanism = :load
-ActionController::Base.consider_all_requests_local = true
-ActionController::Base.perform_caching = false
+# Enable the breakpoint server that script/breakpointer connects to
+config.breakpoint_server = true
-# The breakpoint server port that script/breakpointer connects to.
-BREAKPOINT_SERVER_PORT = 42531
+# Show full error reports and disable caching
+config.action_controller.consider_all_requests_local = true
+config.action_controller.perform_caching = false
+
+# Don't care if the mailer can't send
+config.action_mailer.raise_delivery_errors = false